@@ -246,6 +246,42 @@ def test_bucket_acls_iam_w_user_project(
     with_user_project.set_iam_policy(policy)
 
 
+def test_bucket_acls_w_metageneration_match(storage_client, buckets_to_delete):
+    wrong_metageneration_number = 9
+    bucket_name = _helpers.unique_name("acl-w-metageneration-match")
+    bucket = _helpers.retry_429_503(storage_client.create_bucket)(bucket_name)
+    buckets_to_delete.append(bucket)
+
+    # Exercise bucket ACL with metageneration match
+    acl = bucket.acl
+    acl.group("cloud-developer-relations@google.com").grant_read()
+    bucket.reload()
+
+    with pytest.raises(exceptions.PreconditionFailed):
+        acl.save(if_metageneration_match=wrong_metageneration_number)
+        assert (
+            "READER"
+            not in acl.group("cloud-developer-relations@google.com").get_roles()
+        )
+
+    acl.save(if_metageneration_match=bucket.metageneration)
+    assert "READER" in acl.group("cloud-developer-relations@google.com").get_roles()
+
+    # Exercise default object ACL w/ metageneration match
+    doa = bucket.default_object_acl
+    doa.group("cloud-developer-relations@google.com").grant_owner()
+    bucket.reload()
+
+    with pytest.raises(exceptions.PreconditionFailed):
+        doa.save(if_metageneration_match=wrong_metageneration_number)
+        assert (
+            "OWNER" not in doa.group("cloud-developer-relations@google.com").get_roles()
+        )
+
+    doa.save(if_metageneration_match=bucket.metageneration)
+    assert "OWNER" in doa.group("cloud-developer-relations@google.com").get_roles()
+
+
 def test_bucket_copy_blob(
     storage_client, buckets_to_delete, blobs_to_delete, user_project,
 ):
@@ -770,21 +806,22 @@ def test_ubla_set_unset_preserves_acls(
     assert blob_acl_before == blob_acl_after
 
 
-def test_new_bucket_created_w_unspecified_pap(
+def test_new_bucket_created_w_inherited_pap(
     storage_client, buckets_to_delete, blobs_to_delete,
 ):
     from google.cloud.storage import constants
 
-    bucket_name = _helpers.unique_name("new-w-pap-unspecified")
+    bucket_name = _helpers.unique_name("new-w-pap-inherited")
     bucket = storage_client.bucket(bucket_name)
     bucket.iam_configuration.uniform_bucket_level_access_enabled = True
     bucket.create()
     buckets_to_delete.append(bucket)
 
-    assert (
-        bucket.iam_configuration.public_access_prevention
-        == constants.PUBLIC_ACCESS_PREVENTION_UNSPECIFIED
-    )
+    # TODO: Remove unspecified after changeover is complete
+    assert bucket.iam_configuration.public_access_prevention in [
+        constants.PUBLIC_ACCESS_PREVENTION_UNSPECIFIED,
+        constants.PUBLIC_ACCESS_PREVENTION_INHERITED,
+    ]
 
     bucket.iam_configuration.public_access_prevention = (
         constants.PUBLIC_ACCESS_PREVENTION_ENFORCED
@@ -819,6 +856,7 @@ def test_new_bucket_created_w_unspecified_pap(
         blob.make_public()
 
 
+@pytest.mark.skip(reason="Unspecified PAP is changing to inherited")
 def test_new_bucket_created_w_enforced_pap(
     storage_client, buckets_to_delete, blobs_to_delete,
 ):
@@ -838,12 +876,13 @@ def test_new_bucket_created_w_enforced_pap(
     )
 
     bucket.iam_configuration.public_access_prevention = (
-        constants.PUBLIC_ACCESS_PREVENTION_UNSPECIFIED
+        constants.PUBLIC_ACCESS_PREVENTION_INHERITED
     )
     bucket.patch()
 
-    assert (
-        bucket.iam_configuration.public_access_prevention
-        == constants.PUBLIC_ACCESS_PREVENTION_UNSPECIFIED
-    )
+    # TODO: Remove unspecified after changeover is complete
+    assert bucket.iam_configuration.public_access_prevention in [
+        constants.PUBLIC_ACCESS_PREVENTION_UNSPECIFIED,
+        constants.PUBLIC_ACCESS_PREVENTION_INHERITED,
+    ]
     assert not bucket.iam_configuration.uniform_bucket_level_access_enabled
