@@ -228,3 +228,18 @@ class TestConnection(unittest.TestCase):
         self.assertEqual(conn.ALLOW_AUTO_SWITCH_TO_MTLS_URL, False)
         self.assertEqual(conn.API_BASE_URL, "http://foo")
         self.assertEqual(conn.API_BASE_MTLS_URL, "https://storage.mtls.googleapis.com")
+
+    def test_duplicate_user_agent(self):
+        # Regression test for issue #565
+        from google.cloud._http import ClientInfo
+        from google.cloud.storage.batch import Batch
+        from google.cloud.storage import __version__
+
+        client_info = ClientInfo(user_agent="test/123")
+        conn = self._make_one(object(), client_info=client_info)
+        expected_user_agent = "test/123 gcloud-python/{} ".format(__version__)
+        self.assertEqual(conn._client_info.user_agent, expected_user_agent)
+
+        client = mock.Mock(_connection=conn, spec=["_connection"])
+        batch = Batch(client)
+        self.assertEqual(batch._client_info.user_agent, expected_user_agent)
